@@ -14,6 +14,7 @@ class controller:
 
     def set_aux_servo(self, name, value):
         self._set_aux_servo(name, value)
+
     # Override this to change what happens when you set a aux servo
     def _set_aux_servo(self, name, value):
         pass
@@ -23,3 +24,9 @@ class controller:
 
     def _set_json(self, data):
         pass
+
+    def get_json(self):
+        return self._get_json()
+
+    def set_json(self, data):
+        self._set_json(data)
